==> mobile_pos-1.0.1.tar.gz: lib/src/shared_widgets/transaction_item.dart <==
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/bankbox_transaction_model.dart';
import 'package:mobile_pos/src/shared_widgets/bankbox_money_text.dart';
import 'package:mobile_pos/src/shared_widgets/bankbox_transaction_icon.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/transaction_details.dart';

class BankBoxTransactionItem extends StatelessWidget {
  final Transaction model;
  final bool showBorder;
  const BankBoxTransactionItem({
    required this.model,
    required this.showBorder,
    super.key,
  });

  @override
  Widget build(BuildContext context) {
    return InkWell(
      highlightColor: Colors.transparent,
      splashColor: Colors.transparent,
      onTap: () {
        pushRoute(
            context,
            TransactionDetails(
              transaction: model,
            ));
      },
      child: Container(
        padding: const EdgeInsets.symmetric(vertical: 14),
        decoration: BoxDecoration(
            border: showBorder
                ? Border(
                    bottom: BorderSide(
                        width: 1.8,
                        color: pluginTheme.isLightTheme
                            ? AppColors.lightGrey3
                            : AppColors.lightGrey3.withOpacity(0.04)))
                : null),
        width: double.infinity,
        child: Row(children: [
          Hero(
            tag: model.id,
            child: BankBoxTransactionIcon(
              showRoundedBorder: true,
              model: model,
            ),
          ),
          const Gap(12),
          Expanded(
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text("BankBox Payment", //model.getTransactionName(),
                    maxLines: 1,
                    overflow: TextOverflow.ellipsis,
                    style: headling1.copyWith(
                        fontSize: 14,
                        color: pluginTheme.isLightTheme
                            ? AppColors.darkGrey
                            : Colors.white)),
                const Gap(4),
                FittedBox(
                  child: Row(
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: [
                      Text(model.paymentData.maskedPAN,
                          maxLines: 1,
                          overflow: TextOverflow.ellipsis,
                          style: subtitle.copyWith(fontSize: 12)),
                      Container(
                        height: 4,
                        margin: const EdgeInsets.symmetric(horizontal: 4),
                        width: 4,
                        decoration: BoxDecoration(
                            shape: BoxShape.circle,
                            color: AppColors.ravenPayGrey3),
                      ),
                      Text(
                        DateFormatter.format(model.createdAt,
                            format: "h:mm aa"),
                        style: subtitle.copyWith(fontSize: 10),
                      )
                    ],
                  ),
                )
              ],
            ),
          ),
          const Gap(32),
          Column(
            crossAxisAlignment: CrossAxisAlignment.end,
            children: [
              BankBoxMoneyText(
                amount: double.tryParse(model.amount) ?? 0.0,
                fontSize: 12,
                fontWeight: FontWeight.w700,
                color: pluginTheme.isLightTheme
                    ? AppColors.darkGrey
                    : Colors.white,
                floorAmount: true,
              ),
              const Gap(4),
              Text(
                model.paymentData.responseCode == "00" ? "Credit" : "Failed",
                style: subtitle.copyWith(
                    fontSize: 10,
                    color: model.paymentData.responseCode == "00"
                        ? AppColors.ravenSuccessColor
                        : AppColors.ravenRed),
              )
            ],
          )
        ]),
      ),
    );
  }
}

==> mobile_pos-1.1.1.tar.gz: lib/src/shared_widgets/transaction_item.dart <==
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/bankbox_transaction_model.dart';
import 'package:mobile_pos/src/shared_widgets/bankbox_money_text.dart';
import 'package:mobile_pos/src/shared_widgets/bankbox_transaction_icon.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/transaction_details.dart';

class BankBoxTransactionItem extends StatelessWidget {
  final Transaction model;
  final bool showBorder;
  const BankBoxTransactionItem({
    required this.model,
    required this.showBorder,
    super.key,
  });

  @override
  Widget build(BuildContext context) {
    return InkWell(
      highlightColor: Colors.transparent,
      splashColor: Colors.transparent,
      onTap: () {
        pushRoute(
            context,
            TransactionDetails(
              transaction: model,
            ));
      },
      child: Container(
        padding: const EdgeInsets.symmetric(vertical: 14),
        decoration: BoxDecoration(
            border: showBorder
                ? Border(
                    bottom: BorderSide(
                        width: 1.8,
                        color: pluginTheme.isLightTheme
                            ? AppColors.lightGrey3
                            : AppColors.lightGrey3.withOpacity(0.04)))
                : null),
        width: double.infinity,
        child: Row(children: [
          Hero(
            tag: model.id,
            child: BankBoxTransactionIcon(
              showRoundedBorder: true,
              model: model,
            ),
          ),
          const Gap(12),
          Expanded(
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text("BankBox Payment", //model.getTransactionName(),
                    maxLines: 1,
                    overflow: TextOverflow.ellipsis,
                    style: headling1.copyWith(
                        fontSize: 14,
                        color: pluginTheme.isLightTheme
                            ? AppColors.darkGrey
                            : Colors.white)),
                const Gap(4),
                FittedBox(
                  child: Row(
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: [
                      Text(model.paymentData.maskedPAN,
                          maxLines: 1,
                          overflow: TextOverflow.ellipsis,
                          style: subtitle.copyWith(fontSize: 12)),
                      Container(
                        height: 4,
                        margin: const EdgeInsets.symmetric(horizontal: 4),
                        width: 4,
                        decoration: BoxDecoration(
                            shape: BoxShape.circle,
                            color: AppColors.ravenPayGrey3),
                      ),
                      Text(
                        DateFormatter.format(model.createdAt,
                            format: "h:mm aa"),
                        style: subtitle.copyWith(fontSize: 10),
                      )
                    ],
                  ),
                )
              ],
            ),
          ),
          const Gap(32),
          Column(
            crossAxisAlignment: CrossAxisAlignment.end,
            children: [
              BankBoxMoneyText(
                amount: double.tryParse(model.amount ?? "0") ?? 0.0,
                fontSize: 12,
                fontWeight: FontWeight.w700,
                color: pluginTheme.isLightTheme
                    ? AppColors.darkGrey
                    : Colors.white,
                floorAmount: true,
              ),
              const Gap(4),
              Text(
                model.paymentData.responseCode == "00" ? "Credit" : "Failed",
                style: subtitle.copyWith(
                    fontSize: 10,
                    color: model.paymentData.responseCode == "00"
                        ? AppColors.ravenSuccessColor
                        : AppColors.ravenRed),
              )
            ],
          )
        ]),
      ),
    );
  }
}
